==> edge-login-ui-rn-0.11.0.tgz: package/lib/components/modals/RequestPermissionsModal.js <==
import * as React from 'react';
import s from '../../common/locales/strings';
import { Checkbox } from '../themed/Checkbox';
import { MainButton } from '../themed/MainButton';
import { ThemedModal } from '../themed/ThemedModal';
import { MessageText, TitleText } from '../themed/ThemedText';
export function RequestPermissionsModal(props) {
    const { bridge, choices, message } = props;
    const [selection, setSelection] = React.useState(Object.assign({ enable: false }, choices));
    const handleCancel = () => bridge.resolve(undefined);
    const handlePress = (choice, value) => {
        const newSelection = Object.assign(Object.assign({}, selection), { [choice]: value !== null && value !== void 0 ? value : !selection[choice] });
        setSelection(newSelection);
        // A confirmation button was pressed:
        if (choice === 'enable') {
            bridge.resolve(newSelection);
        }
    };
    return (React.createElement(ThemedModal, { bridge: bridge, paddingRem: 1, warning: true, onCancel: handleCancel },
        React.createElement(TitleText, null, s.strings.alert_modal_title),
        React.createElement(MessageText, null, message),
        React.createElement(Checkbox, { onChange: () => handlePress('optInPriceChanges'), value: selection.optInPriceChanges, textStyle: {} }, s.strings.notifications_opt_in_price_changes),
        React.createElement(Checkbox, { onChange: () => handlePress('optInMarketing'), value: selection.optInMarketing, textStyle: {} }, s.strings.notifications_opt_in_marketing),
        React.createElement(MainButton, { label: s.strings.enable, marginRem: 0.5, type: "primary", onPress: () => handlePress('enable', true) }),
        React.createElement(MainButton, { label: s.strings.cancel, marginRem: 0.5, type: "escape", onPress: () => handlePress('enable', false) })));
}

==> edge-login-ui-rn-2.1.0.tgz: package/lib/components/modals/RequestPermissionsModal.js <==
import * as React from 'react';
import s from '../../common/locales/strings';
import { Checkbox } from '../themed/Checkbox';
import { MainButton } from '../themed/MainButton';
import { ThemedModal } from '../themed/ThemedModal';
import { MessageText, TitleText } from '../themed/ThemedText';
export function RequestPermissionsModal(props) {
    const { bridge, choices, message } = props;
    const [selection, setSelection] = React.useState(Object.assign({ enable: false }, choices));
    const handleCancel = () => bridge.resolve(undefined);
    const handlePress = (choice, value) => {
        const newSelection = Object.assign(Object.assign({}, selection), { [choice]: value !== null && value !== void 0 ? value : !selection[choice] });
        setSelection(newSelection);
        // A confirmation button was pressed:
        if (choice === 'enable') {
            bridge.resolve(newSelection);
        }
    };
    return (React.createElement(ThemedModal, { bridge: bridge, paddingRem: 1, warning: true, onCancel: handleCancel },
        React.createElement(TitleText, null, s.strings.security_is_our_priority_modal_title),
        React.createElement(MessageText, null, message),
        React.createElement(Checkbox, { onChange: () => handlePress('optInPriceChanges'), value: selection.optInPriceChanges, textStyle: {} }, s.strings.notifications_opt_in_price_changes),
        React.createElement(Checkbox, { onChange: () => handlePress('optInMarketing'), value: selection.optInMarketing, textStyle: {} }, s.strings.notifications_opt_in_marketing),
        React.createElement(MainButton, { label: s.strings.enable, marginRem: 0.5, type: "primary", onPress: () => handlePress('enable', true) }),
        React.createElement(MainButton, { label: s.strings.cancel, marginRem: 0.5, type: "escape", onPress: () => handlePress('enable', false) })));
}
